@@ -1,4 +1,4 @@
-/* Copyright 2021 VMware, Inc.
+/* Copyright 2022 VMware, Inc.
  * SPDX-License-Identifier: Apache-2.0
  */
 
@@ -21,7 +21,6 @@ int dns_server_new(DNSServer **ret) {
                 return -ENOMEM;
 
         *ret = steal_pointer(a);
-
         return 0;
 }
 
@@ -36,7 +35,7 @@ void dns_servers_free(DNSServers *d) {
         if (d->dns_servers)
                 g_sequence_free(d->dns_servers);
 
-        g_free(d);
+        free(d);
 }
 
 int dns_servers_new(DNSServers **ret) {
@@ -71,12 +70,12 @@ static int dns_compare_func(gconstpointer x, gconstpointer y, gpointer user_data
                 return a->ifindex - b->ifindex;
 
         switch(a->address.family) {
-        case AF_INET:
-                return memcmp(&a->address.in, &b->address.in, sizeof(struct in_addr));
-        case AF_INET6:
-                return memcmp(&a->address.in6, &b->address.in6, sizeof(struct in6_addr));
-        default:
-                break;
+                case AF_INET:
+                        return memcmp(&a->address.in, &b->address.in, sizeof(struct in_addr));
+                case AF_INET6:
+                        return memcmp(&a->address.in6, &b->address.in6, sizeof(struct in6_addr));
+                default:
+                        break;
         }
 
         return 0;
@@ -124,8 +123,8 @@ void dns_domain_free(void *d) {
         if (!d)
                 return;
 
-        g_free(p->domain);
-        g_free(p);
+        free(p->domain);
+        free(p);
 }
 
 int dns_domains_new(DNSDomains **ret) {
@@ -150,7 +149,7 @@ void dns_domains_free(DNSDomains *d) {
         if (d->dns_domains)
                 g_sequence_free(d->dns_domains);
 
-        g_free(d);
+        free(d);
 }
 
 static int dns_domain_compare_func(gconstpointer x, gconstpointer y, gpointer user_data) {
@@ -254,16 +253,19 @@ int add_dns_server_and_domain_to_resolv_conf(DNSServers *dns, char **domains) {
 
 /* write to /etc/systemd/resolved.conf */
 int add_dns_server_and_domain_to_resolved_conf(DNSServers *dns, char **domains) {
-        _cleanup_(key_file_freep) GKeyFile *key_file = NULL;
+        _cleanup_(gkey_file_freep) GKeyFile *key_file = NULL;
         _cleanup_(g_error_freep) GError *e = NULL;
         int r;
 
-        r = load_config_file("/etc/systemd/resolved.conf", &key_file);
-        if (r < 0)
-                return r;
+        key_file = g_key_file_new();
+        if (!key_file)
+                return -ENOMEM;
+
+        if (!g_key_file_load_from_file(key_file, "/etc/systemd/resolved.conf", G_KEY_FILE_NONE, &e))
+                return -ENODATA;
 
         if (dns) {
-                _auto_cleanup_ char *dns_line = NULL, *l = NULL;
+                _auto_cleanup_ char *dns_line = NULL;
                 _auto_cleanup_strv_ char **s = NULL;
 
                 dns_line = g_key_file_get_string(key_file, "Resolve", "DNS", &e);
@@ -304,7 +306,7 @@ int add_dns_server_and_domain_to_resolved_conf(DNSServers *dns, char **domains)
         }
 
         if (domains) {
-                _auto_cleanup_ char *domain_line = NULL, *l = NULL;
+                _auto_cleanup_ char *domain_line = NULL;
                 _auto_cleanup_strv_ char **s = NULL;
                 char **j;
 
